==> dashbuilder-navigation-client-0.9.0-20170907.150637-13-sources.jar: org/dashbuilder/client/navigation/layout/editor/NavTabListDragComponent.java <==
/*
 * Copyright 2016 JBoss, by Red Hat, Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dashbuilder.client.navigation.layout.editor;

import javax.enterprise.context.Dependent;
import javax.inject.Inject;

import org.dashbuilder.client.navigation.NavigationManager;
import org.dashbuilder.client.navigation.resources.i18n.NavigationConstants;
import org.dashbuilder.client.navigation.widget.NavCarouselWidget;
import org.dashbuilder.client.navigation.widget.NavItemSelectionModal;
import org.dashbuilder.client.navigation.widget.NavTabListWidget;

/**
 * A layout editor's navigation component that shows a list of tabs providing links to workbench assets
 */
@Dependent
public class NavTabListDragComponent extends AbstractNavDragComponent {

    @Inject
    public NavTabListDragComponent(NavigationManager navigationManager,
                                   NavDragComponentRegistry navDragComponentRegistry,
                                   NavItemSelectionModal navItemSelectionModal,
                                   NavTabListWidget navWidget) {
        super(navigationManager,
                navDragComponentRegistry,
                navItemSelectionModal,
                navWidget);
    }

    @Override
    public String getDragComponentTitle() {
        return NavigationConstants.INSTANCE.navTabListDragComponent();
    }

    @Override
    public String getDragComponentHelp() {
        return NavigationConstants.INSTANCE.navTabListDragComponentHelp();
    }
}

==> dashbuilder-navigation-client-1.1.0-20171125.192439-65-sources.jar: org/dashbuilder/client/navigation/layout/editor/NavTabListDragComponent.java <==
/*
 * Copyright 2016 JBoss, by Red Hat, Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dashbuilder.client.navigation.layout.editor;

import javax.enterprise.context.Dependent;
import javax.inject.Inject;

import com.google.gwt.dom.client.Style;
import com.google.gwt.user.client.ui.IsWidget;
import org.dashbuilder.client.navigation.NavigationManager;
import org.dashbuilder.client.navigation.plugin.PerspectivePluginManager;
import org.dashbuilder.client.navigation.resources.i18n.NavigationConstants;
import org.dashbuilder.client.navigation.widget.NavComponentConfigModal;
import org.dashbuilder.client.navigation.widget.NavTabListWidget;
import org.uberfire.ext.layout.editor.client.api.RenderingContext;

/**
 * A layout editor's navigation component that shows a list of tabs providing links to workbench assets
 */
@Dependent
public class NavTabListDragComponent extends AbstractNavDragComponent {

    @Inject
    public NavTabListDragComponent(NavigationManager navigationManager,
                                   PerspectivePluginManager pluginManager,
                                   NavComponentConfigModal navComponentConfigModal,
                                   NavTabListWidget navWidget) {
        super(navigationManager,
                pluginManager,
                navComponentConfigModal,
                navWidget);
    }

    @Override
    public String getDragComponentTitle() {
        return NavigationConstants.INSTANCE.navTabListDragComponent();
    }

    @Override
    public String getDragComponentNavGroupHelp() {
        return NavigationConstants.INSTANCE.navTabListDragComponentNavGroupHelp();
    }

    @Override
    public IsWidget getPreviewWidget(RenderingContext ctx) {
        IsWidget widget = super.getPreviewWidget(ctx);
        widget.asWidget().getElement().getStyle().setPosition(Style.Position.ABSOLUTE);
        widget.asWidget().getElement().getStyle().setWidth(96, Style.Unit.PCT);
        return widget;
    }
}
